summaryrefslogtreecommitdiff
path: root/libdiskfs/diskfs.h
diff options
context:
space:
mode:
Diffstat (limited to 'libdiskfs/diskfs.h')
-rw-r--r--libdiskfs/diskfs.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/libdiskfs/diskfs.h b/libdiskfs/diskfs.h
index 08dc2a8d..f086b5a8 100644
--- a/libdiskfs/diskfs.h
+++ b/libdiskfs/diskfs.h
@@ -838,15 +838,19 @@ diskfs_create_node (struct node *dir, char *name, mode_t mode,
struct node **newnode, struct protid *cred,
struct dirstat *ds);
-/* Create and return a protid for an existing peropen. The uid set is
- UID (length NUIDS); the gid set is GID (length NGIDS). The node
+/* Create and return a protid for an existing peropen PO in CRED. The uid
+ set is UID (length NUIDS); the gid set is GID (length NGIDS). The node
PO->np must be locked. */
+error_t diskfs_create_protid (struct peropen *po, uid_t *uids, int nuids,
+ uid_t *gids, int ngids, struct protid **cred);
+
+/* Backward compatibility. Use diskfs_create_protid. */
struct protid *diskfs_make_protid (struct peropen *cred, uid_t *uids,
int nuids, uid_t *gids, int ngids);
/* Build and return a protid which has no user identification for
peropen PO. The node PO->np must be locked. */
-struct protid *diskfs_start_protid (struct peropen *po);
+error_t diskfs_start_protid (struct peropen *po, struct protid **cred);
/* Finish building protid CRED started with diskfs_start_protid;
the uid set is UID (length NUIDS); the gid set is GID (length NGIDS). */
@@ -838,15 +838,19 @@ diskfs_create_node (struct node *dir, char *name, mode_t mode,
struct protid *diskfs_make_protid (struct peropen *cred, uid_t *uids,
int nuids, uid_t *gids, int ngids);
-/* Build and return a protid which has no user identification for
+/* Build and return in CRED a protid which has no user identification, for
peropen PO. The node PO->np must be locked. */